@@ -1,8 +1,6 @@
 test_that("cdi", {
-  if (!covr::in_covr()) {
-    skip_on_cran()
-    skip_if_offline()
-  }
+  skip_on_cran()
+  skip_if_offline()
 
   # first call
   cdi_1 <- cdi_get()
@@ -15,4 +13,4 @@ test_that("cdi", {
 
   idi <- idi_get()
   expect_true(nrow(idi) > 0)
-})
\ No newline at end of file
+})
